#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_REAL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_REAL_HPP_INCLUDED

#include <boost/simd/constant/include/constants/real.hpp>

#endif
